pub enum Entry<'a, K: 'a, V: 'a, A: Allocator + Clone = Global> {
Vacant(VacantEntry<'a, K, V, A>),
Occupied(OccupiedEntry<'a, K, V, A>),
}Expand description
Variants
Vacant(VacantEntry<'a, K, V, A>)
A vacant entry.
Occupied(OccupiedEntry<'a, K, V, A>)
An occupied entry.
Implementations
Sourceimpl<'a, K: Ord, V, A: Allocator + Clone> Entry<'a, K, V, A>
impl<'a, K: Ord, V, A: Allocator + Clone> Entry<'a, K, V, A>
1.0.0 · Sourcepub fn or_insert(self, default: V) -> &'a mut V
pub fn or_insert(self, default: V) -> &'a mut V
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
1.0.0 · Sourcepub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
pub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
Sourcepub fn or_try_insert_with<F: FnOnce() -> Result<V, E>, E>(
self,
default: F,
) -> Result<&'a mut V, E>
🔬This is a nightly-only experimental API. (try_entry #157354)
pub fn or_try_insert_with<F: FnOnce() -> Result<V, E>, E>( self, default: F, ) -> Result<&'a mut V, E>
try_entry #157354)Ensures a value is in the entry by inserting the result of a fallible default function if empty, and returns a mutable reference to the value in the entry.
This method works identically to or_insert_with except that the default function
should return a Result and, in the case of an error, the error is propagated.
Examples
1.50.0 · Sourcepub fn or_insert_with_key<F: FnOnce(&K) -> V>(self, default: F) -> &'a mut V
pub fn or_insert_with_key<F: FnOnce(&K) -> V>(self, default: F) -> &'a mut V
Ensures a value is in the entry by inserting, if empty, the result of the default function.
This method allows for generating key-derived values for insertion by providing the default
function a reference to the key that was moved during the .entry(key) method call.
The reference to the moved key is provided so that cloning or copying the key is
unnecessary, unlike with .or_insert_with(|| ... ).
Examples
Sourcepub fn or_try_insert_with_key<F: FnOnce(&K) -> Result<V, E>, E>(
self,
default: F,
) -> Result<&'a mut V, E>
🔬This is a nightly-only experimental API. (try_entry #157354)
pub fn or_try_insert_with_key<F: FnOnce(&K) -> Result<V, E>, E>( self, default: F, ) -> Result<&'a mut V, E>
try_entry #157354)Ensures a value is in the entry by inserting, if empty, the result of the default function.
This method allows for generating key-derived values for insertion by providing the default
function a reference to the key that was moved during the entry(key) method call.
This method works identically to or_insert_with_key except that the default function
should return a Result and, in the case of an error, the error is propagated.
Examples
1.26.0 · Sourcepub fn and_modify<F>(self, f: F) -> Self
pub fn and_modify<F>(self, f: F) -> Self
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
1.92.0 · Sourcepub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>
pub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>
Sets the value of the entry, and returns an OccupiedEntry.
Examples